OC.L10N.register(
    "files_versions",
    {
    "Versions" : "Versi",
    "Failed to revert {file} to revision {timestamp}." : "Gagal kembalikan {file} ke semakan {timestamp}.",
    "Restore" : "Pulihkan",
    "No other versions available" : "Tiada lagi versi lain"
},
"nplurals=1; plural=0;");
